Param (
	[string]$ServiceContext
)

if (-Not $ServiceContext)
{
	Write-Host ""
	Write-Host "DESCRIPTION"
	Write-Host "    This script updates the SystemUtilityTypeName property information on all existing BDC models created by Business Connectivity Service custom connector for SQL Server using Esri Maps Connect Workflow. Use this command to upgrade existing BDC models from previous Esri Maps for SharePoint versions to the current installer version."
	Write-Host ""
	Write-Host "SYNTAX"
	Write-Host "    UpdateCustomBCSConnectors.ps1 -ServiceContext"
	Write-Host ""
	Exit
}

if (-Not (Get-PsSnapin Microsoft.SharePoint.PowerShell))
{
	Add-PsSnapin Microsoft.SharePoint.PowerShell
}

if ($PSScriptRoot -eq $null) 
{
    $PSScriptRoot = Split-Path $MyInvocation.MyCommand.Path -Parent
}
		
$AssemblyPath = Join-Path $PSScriptRoot "Setup.exe"
$Assembly = [System.Reflection.Assembly]::LoadFrom($AssemblyPath)
$AssemblyVersion = $Assembly.GetName() | Select -ExpandProperty "Version"
$AssemblyVersionAsString = $AssemblyVersion.ToString()
$AssemblyPublicTokenBytes = $Assembly.GetName().GetPublicKeyToken()

$TokenStringBuilder = New-Object System.Text.StringBuilder
For($i=0; $i -lt $AssemblyPublicTokenBytes.Length; $i++) 
{
	$TokenStringBuilder.Append([String]::Format("{0:x2}", $AssemblyPublicTokenBytes[$i])) | Out-Null
}

$SystemUtilityTypeName = [String]::Format("ESRI.ArcGIS.Mapping.SharePoint.Core.SqlServerConnector, ESRI.ArcGIS.Mapping.SharePoint.Core, Version={0}, Culture=neutral, PublicKeyToken={1}", $AssemblyVersionAsString, $TokenStringBuilder.ToString())

$Bdc = Get-SPBusinessDataCatalogMetaDataObject -BdcObjectType Catalog -ServiceContext $ServiceContext
$Lobs = $Bdc.GetLobSystems("*")
Foreach($Lob in $Lobs)
{
	$NameSpace = $Lob.Entities | Select -ExpandProperty "Namespace"
	if ($NameSpace -eq "ESRI.ArcGIS.Mapping.SharePoint") 
	{
		# Write-Host ($Lob.Entities | Select -ExpandProperty "Name")
		Set-SPBusinessDataCatalogMetadataObject -Identity $Lob -PropertyName "SystemUtilityTypeName" -PropertyValue $SystemUtilityTypeName 
		$Lob.Update()
	}	
}
